@@ -237,7 +237,7 @@ def gdal_Buffer(src_dataset, dst_dataset=None, distance=10, verbose=True):
     if ds is None:
         print("gdal_Buffer error: File <%s> does not exits! " %src_dataset)
         return False
-    proj,gt = ds.GetProjection(), ds.GetGeoTransform()
+    prj,gt = ds.GetProjection(), ds.GetGeoTransform()
     m,n = ds.RasterYSize,ds.RasterXSize
     band= ds.GetRasterBand(1)
     no_data = band.GetNoDataValue()
@@ -269,7 +269,7 @@ def gdal_Buffer(src_dataset, dst_dataset=None, distance=10, verbose=True):
         h += 1
     ds, temp_array, data = None, None, None
 
-    Numpy2Gdal(out_array, gt, prj, dst_dataset, no_data)
+    Numpy2Gdal(out_array.as("b"), gt, prj, dst_dataset, no_data)
     out_array=None
     return True
 
